#!/bin/bash
#
# packager           : Fred. Galusik <fredg> (fredgk~AT~gmail.com)
# sources locations  : http://www.geocities.com/SiliconValley/Lakes/5147/sidplay/
# last revised       : 24/02/07

softname='libsidplay'
softversion='1.36.59'
packageversion='46.1'

arch='i486'
cpu='i686'

prefix=/usr

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tgz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# put slack-desc in place
cat <<EOF > $dest/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
$softname: A multi-platform C64 music player and SID chip emulator
$softname:
$softname: SIDPLAY emulates the Sound Interface Device chip (MOS 6581, 
$softname: commonly called SID) and the Micro Processor Unit (MOS 6510) 
$softname: of the Commodore 64 on your computer.
$softname: 
$softname:
$softname:
$softname: 
$softname:
$softname: 
EOF

# extract the source code
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
cd $buildir
tar xzvf $srcpkg
cd $src

# configure package for compilation

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
	  --prefix=$prefix \
	  --libdir=/usr/lib \
	  --includedir=/usr/include \
	  --enable-static=no \
	  --disable-debug \
	  --program-prefix="" \
      --program-suffix="" \

# make package and install it to the target directory
    make
    make install DESTDIR=$dest
    
# add and remove unneeded doc dir
cp -a \
      AUTHORS COPYING INSTALL DEVELOPER \
      $dest/usr/doc/$softname-$softversion
rm -rf $dest/usr/share/doc

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# put the ZenWalk build in the right directory
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 640 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -type d -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.tgz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5   
